Examples
========

Here's a simple example of implementing Dijkstra's algorithm using a ``PQDict``.

.. raw:: html

	<script src="https://gist.github.com/nvictus/7854213.js"></script>


-----


This is an example of an algorithm that simulates stochastic chemical reactions.

.. raw:: html

	<script src="https://gist.github.com/nvictus/7853997.js"></script>


Output:

.. image:: gillespie-output.png